@@ -396,7 +396,12 @@ void Game::createBonus()
         for (int i = 0; i < nQuarterSize; ++i)
         {
             nShuffle = granatier::RNG::fromRange(0, nQuarterSize-1);
-            bonusTypeList.swap(i, nShuffle);
+
+#if QT_VERSION < QT_VERSION_CHECK(5, 13, 0)
+        bonusTypeList.swap(i, nShuffle);
+#else
+        bonusTypeList.swapItemsAt(i, nShuffle);
+#endif
         }
 
         for (int i = 0; i < nQuarterSize; ++i)
