@@ -52,13 +52,13 @@ int main(int argc, char** argv)
         dataDirs.append(QStringLiteral("themes"));
 
         // migrate arenas, players and themes
-        foreach(const QString &dataDir, dataDirs)
+        for(const auto& dataDir: dataDirs)
         {
             QDir sourceDir(sourceBasePath + dataDir);
             if(!sourceDir.exists()) continue;
             QStringList fileNames = sourceDir.entryList(QDir::Files | QDir::Dirs | QDir::NoDotAndDotDot | QDir::NoSymLinks);
             QDir().mkpath(targetBasePath + dataDir);
-            foreach (const QString &fileName, fileNames)
+            for(const auto& fileName: fileNames)
             {
                 targetFilePath = targetBasePath + dataDir + QLatin1Char('/') + fileName;
                 if(!QFile::exists(targetFilePath))
@@ -76,10 +76,11 @@ int main(int argc, char** argv)
     KLocalizedString::setApplicationDomain("granatier");
 
     // About Granatier
-    KAboutData about(QStringLiteral("granatier"),  i18n("Granatier"), QStringLiteral("1.3.1"),
+    KAboutData about(QStringLiteral("granatier"),  i18n("Granatier"), QStringLiteral("1.4.0"),
         i18n("Granatier is a Bomberman Clone!"),
         KAboutLicense::GPL, i18n("Copyright (c) 2009-2015 The Granatier Team!"));
     about.addAuthor(i18n("Mathias Kraus"), i18n("Maintainer"), QStringLiteral("k.hias@gmx.de"));
+    about.addCredit(i18n("Arturo Silva"), i18n("Most of the beautiful granatier graphics"));
     about.addCredit(i18n("Thomas Gallinari"), i18n("Developer of Kapman, which was the base of Granatier"), QStringLiteral("tg8187@yahoo.fr"));
     about.addCredit(i18n("Pierre-Benoit Besse"), i18n("Developer of Kapman, which was the base of Granatier"), QStringLiteral("besse.pb@gmail.com"));
     about.addCredit(i18n("Romain Castan"), i18n("Developer of Kapman, which was the base of Granatier"), QStringLiteral("romaincastan@gmail.com"));
